==> jc-1.4.0.tar.gz: javax/swing/text/AbstractDocument__24DefaultDocumentEvent.h <==
// public class javax.swing.text.AbstractDocument$DefaultDocumentEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a7687d7c0cb4b3ab javax_swing_text_AbstractDocument__24DefaultDocumentEvent
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit
// @dep_class 4e948e13ad27d674 javax_swing_undo_CompoundEdit

// header file dependencies
// @dep_header javax_swing_undo_CompoundEdit

#include "javax/swing/undo/CompoundEdit.h"

#ifndef _JC_javax_swing_text_AbstractDocument__24DefaultDocumentEvent_H_
#define _JC_javax_swing_text_AbstractDocument__24DefaultDocumentEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_DocumentEvent__24ElementChange$object;
struct _jc_javax_swing_event_DocumentEvent__24EventType$object;
struct _jc_javax_swing_text_AbstractDocument$object;
struct _jc_javax_swing_text_Document$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_refs	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_refs;
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_nonrefs	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$refs	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$refs;
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$nonrefs	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object;

typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$fields_struct	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$fields_struct;
typedef const struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vmethods	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vmethods;
typedef const struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtable	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtable;
typedef const struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype;

// Class fields structure
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$fields_struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$class_fields;

// Constructors
extern void _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$_init$726ed82cef68b44f(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_javax_swing_text_AbstractDocument$object *, jint, jint, struct _jc_javax_swing_event_DocumentEvent__24EventType$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getChange$7ee2e74fdd3e1328(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getDocument$4e6440f82a066e79(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);
extern jint _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);
extern jint _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);
extern struct _jc_javax_swing_event_DocumentEvent__24EventType$object *_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getType$8b4ac9dbd68513ef(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getChange$7ee2e74fdd3e1328;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getDocument$4e6440f82a066e79;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getType$8b4ac9dbd68513ef;

// Virtual methods structure
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vmethods {
	struct _jc_object	*(*getChange$7ee2e74fdd3e1328)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_object *);
	struct _jc_object	*(*getDocument$4e6440f82a066e79)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*(*getType$8b4ac9dbd68513ef)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_undo_CompoundEdit$vmethods	javax_swing_undo_CompoundEdit;
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vmethods	javax_swing_text_AbstractDocument__24DefaultDocumentEvent;
};

// Vtype
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_refs {
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*type;
	struct _jc_javax_swing_text_AbstractDocument$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$refs {
    _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_refs	javax_swing_text_AbstractDocument__24DefaultDocumentEvent;
    _jc_javax_swing_undo_CompoundEdit$sub_refs	javax_swing_undo_CompoundEdit;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_nonrefs {
	jint	offset;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_undo_CompoundEdit$sub_nonrefs	javax_swing_undo_CompoundEdit;
    _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_nonrefs	javax_swing_text_AbstractDocument__24DefaultDocumentEvent;
};

// Object instance structure
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object {
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype	*vtype;
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_AbstractDocument__24DefaultDocumentEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$class_object;

#endif	/* _JC_javax_swing_text_AbstractDocument__24DefaultDocumentEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/AbstractDocument__24DefaultDocumentEvent.h <==
// public class javax.swing.text.AbstractDocument$DefaultDocumentEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 69837118fc8d5d27 javax_swing_text_AbstractDocument__24DefaultDocumentEvent
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit
// @dep_class 4e948e13ad27d674 javax_swing_undo_CompoundEdit

// header file dependencies
// @dep_header javax_swing_undo_CompoundEdit

#include "javax/swing/undo/CompoundEdit.h"

#ifndef _JC_javax_swing_text_AbstractDocument__24DefaultDocumentEvent_H_
#define _JC_javax_swing_text_AbstractDocument__24DefaultDocumentEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_DocumentEvent__24ElementChange$object;
struct _jc_javax_swing_event_DocumentEvent__24EventType$object;
struct _jc_javax_swing_text_AbstractDocument$object;
struct _jc_javax_swing_text_Document$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_refs	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_refs;
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_nonrefs	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$refs	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$refs;
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$nonrefs	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object;

typedef struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$fields_struct	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$fields_struct;
typedef const struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vmethods	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vmethods;
typedef const struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtable	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtable;
typedef const struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype;

// Class fields structure
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$fields_struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$class_fields;

// Constructors
extern void _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$_init$726ed82cef68b44f(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_javax_swing_text_AbstractDocument$object *, jint, jint, struct _jc_javax_swing_event_DocumentEvent__24EventType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getChange$7ee2e74fdd3e1328(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getDocument$4e6440f82a066e79(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_event_DocumentEvent__24EventType$object *_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method$getType$8b4ac9dbd68513ef(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getChange$7ee2e74fdd3e1328;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getDocument$4e6440f82a066e79;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$method_info$getType$8b4ac9dbd68513ef;

// Virtual methods structure
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vmethods {
	struct _jc_object	*(*getChange$7ee2e74fdd3e1328)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDocument$4e6440f82a066e79)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*(*getType$8b4ac9dbd68513ef)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_undo_CompoundEdit$vmethods	javax_swing_undo_CompoundEdit;
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vmethods	javax_swing_text_AbstractDocument__24DefaultDocumentEvent;
};

// Vtype
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_refs {
	struct _jc_javax_swing_event_DocumentEvent__24EventType$object	*type;
	struct _jc_javax_swing_text_AbstractDocument$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$refs {
    _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_refs	javax_swing_text_AbstractDocument__24DefaultDocumentEvent;
    _jc_javax_swing_undo_CompoundEdit$sub_refs	javax_swing_undo_CompoundEdit;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_nonrefs {
	jint	offset;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_undo_CompoundEdit$sub_nonrefs	javax_swing_undo_CompoundEdit;
    _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$sub_nonrefs	javax_swing_text_AbstractDocument__24DefaultDocumentEvent;
};

// Object instance structure
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object {
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype	*vtype;
	_jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$vtype _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_AbstractDocument__24DefaultDocumentEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$class_object;

#endif	/* _JC_javax_swing_text_AbstractDocument__24DefaultDocumentEvent_H_ */
